{% extends "master.html" %}

{% block title %} - Overview{% endblock %}

{% block body %}
<div class="container main">
    <div class="current-jobs section">
        <h1>Jobs in Progress</h1>

        {% for job_type in g.job_types %}
        <h2>{{ job_type }}</h2>
        <table class="table table-striped table-bordered table-condensed">
            <thead>
                <tr>
                    <th class="job-id-col">Job ID</th>
                    <th>Phase</th>
                </tr>
            </thead>
            <tbody>
                {% for job in g.jobs[job_type] %}
                <tr>
                    <td>{{ job }}</td>
                    <td>Mapping</td>
                </tr>
                {% else %}
                <tr>
                    <td colspan="2" class="no-jobs">Nothing happening here right now...</td>
                </tr>
                {% endfor %}
            </tbody>
        </table>
        {% else %}
        <table class="no-jobs table table-striped table-bordered table-condensed">
            <thead>
                <tr>
                    <th class="job-id-col">Job ID</th>
                    <th>Phase</th>
                </tr>
            </thead>
            <tbody>
                <tr>
                    <td colspan="2" class="no-jobs">Nothing happening here right now...</td>
                </tr>
            </tbody>
        </table>
        {% endfor %}

        <span class="explain">click a job type to view its activity</span>
    </div>
</div>
{% endblock %}
