<!DOCTYPE HTML>
<html>
<head>
    <meta http-equiv="content-type" content="text/html; charset=utf-8">
    <title>r³{% block title %}{% endblock %}</title>
    {%  block css %}

    <link rel="stylesheet" href="{{ url_for('static', filename='css/reset.css') }}" type="text/css" media="screen" charset="utf-8">
    <link rel="stylesheet" href="{{ url_for('static', filename='css/bootstrap.min.css') }}" type="text/css" media="screen" charset="utf-8">
    <link rel="stylesheet" href="{{ url_for('static', filename='css/progress.css') }}" type="text/css" media="screen" charset="utf-8">
    <link rel="stylesheet" href="{{ url_for('static', filename='css/style.css') }}" type="text/css" media="screen" charset="utf-8">
    {% endblock %}
</head>
<body>
    <header>
        <div class="container">
            <a href="/" alt="overview"><h1>r³ - map reduce service</h1></a>
            <div class="menu">
                <nav>
                    <ul>
                        <li><a href="/" alt="overview">overview</a></li>
                        <li><a href="/job-types" alt="job types">job types</a></li>
                        <li><a href="/mappers" alt="mappers">mappers</a></li>
                        <li><a href="/failed" alt="failed">failed</a></li>
                        <li><a href="/stats" alt="stats">stats</a></li>
                    </ul>
                </nav>
                <aside>
                <p>r³ service status: <span class="running">{{ g.server['r3_service_status'] }}</span> :: active mappers: <span class="active-workers">{{ g.mappers|count }}</span> :: available job types: <span class="active-job-types">{{ g.job_types|count }}</span></p>
                    <p>running on <span class="redis-url">{{ g.config['WEB_HOST'] }}:{{ g.config['WEB_PORT'] }}</span> connected to Redis on <span class="redis-url">{{ g.config['REDIS_HOST'] }}:{{ g.config['REDIS_PORT'] }}</span></p>
                </aside>

            </div>
        </div>
    </header>
    <div class="body">
    {% block body %}
    {% endblock %}
    </div>

    <footer>
        <div class="cell">
            <a href="http://github.com/heynemann/r3" alt="r3 map reduce service">powered by r³ version {{ g.server['r3_version'] }}</a>
        </div>
    </footer>

    {% block js %}
    <script type="text/javascript" src="{{ url_for('static', filename='js/jquery-1.7.2.min.js') }}" charset="utf-8"></script>
    <script type="text/javascript" src="{{ url_for('static', filename='js/bootstrap.min.js') }}" charset="utf-8"></script>
    <script type="text/javascript" src="{{ url_for('static', filename='js/progress.js') }}" charset="utf-8"></script>
    {% endblock %}
</body>
</html>
